@@ -91,7 +91,7 @@ void initialise_pop(double ***ACTION, double ***COST, double *paras, int layer,
             }while(COST[xpos][ypos][layer] > budget_count);
             population[xpos][ypos][agent]++;
             budget_count -= COST[xpos][ypos][layer]; 
-        } /* Should now make random actions allowed by budget */
+        } 
     }
 }
 
@@ -255,23 +255,29 @@ void constrain_costs(double ***population, double ***COST, double *paras,
  *     jaco: The interaction table itself (i.e., Jacobian matrix)
  *     row: The row of the interaction and lookup table being examined
  *     agent: The agent in the population whose fitness is being assessed
+ *     agent_array: The array of agents
+ *     a_row: The row in the agents array where the agent is located
  * ========================================================================== */
 void res_to_counts(double ***population, int **interact_table, double *paras,
-                   double *count_change, double *utilities, double **jaco,
-                   int row, int agent){
+                   double *count_change, double *utilities, double **jaco, 
+                   int row, int agent, double **agent_array, int a_row){
     
-    int i, interest_row, int_num;
-    double foc_effect, lambda;
+    int i, interest_row, int_num, psc, pcu, pca, pfe, phe;
+    double foc_effect;
     
-    int_num = (int) paras[60];
-    lambda  = paras[100];
+    int_num       = (int) paras[60];
+    psc           = (int) paras[74];
+    pcu           = (int) paras[75];
+    pca           = (int) paras[76];
+    pfe           = (int) paras[77];
+    phe           = (int) paras[78];
     
     foc_effect  = 0.0;
-    foc_effect -= population[row][7][agent];  /* Times birth account for repr?*/
-    foc_effect -= population[row][8][agent];
-    foc_effect -= population[row][9][agent]  * lambda;
-    foc_effect += population[row][10][agent] * lambda;
-    foc_effect += population[row][11][agent]; /* But should affect offspring? */
+    foc_effect += population[row][7][agent]  * agent_array[a_row][psc];
+    foc_effect += population[row][8][agent]  * agent_array[a_row][pcu];
+    foc_effect += population[row][9][agent]  * agent_array[a_row][pca];
+    foc_effect += population[row][10][agent] * agent_array[a_row][pfe];
+    foc_effect += population[row][11][agent] * agent_array[a_row][phe];
     interest_row = 0;
     while(interest_row < int_num){
         if(interact_table[interest_row][0] == 0                         &&
@@ -301,24 +307,27 @@ void res_to_counts(double ***population, int **interact_table, double *paras,
  *     agent: The agent in the population whose fitness is being assessed
  *     jaco: The interaction table itself (i.e., Jacobian matrix)
  *     count_change: A vector of how counts have changed as a result of actions
+ *     agent_array: The array of agents
+ *     a_row: The row in the agents array where the agent is located
  * ========================================================================== */
 void land_to_counts(double ***population, int **interact_table, double *paras,
                     double *utilities, int row, int agent, double **jaco,
-                    double *count_change){
+                    double *count_change, double **agent_array, int a_row){
     
-    int i, interest_row, int_num;
-    double foc_effect, feedin;
+    int i, interest_row, int_num, p_tend, p_kill;
+    double foc_effect;
     
     int_num = (int) paras[60];
-    feedin  = paras[79];
+    p_tend  = (int) paras[122];
+    p_kill  = (int) paras[123];
     
     foc_effect   = 0.0;
-    foc_effect  += (population[row][9][agent] * feedin); /* Feed the crop */
-    if(population[row][10][agent] == 1){                 /* Kill the crop */
-        foc_effect = -1;
+    foc_effect  += population[row][9][agent] * agent_array[a_row][p_tend];
+    if(population[row][10][agent] == 1){         /* Kill the crop */
+        foc_effect = agent_array[a_row][p_kill]; /* Note is absolute */
     }
     interest_row = 0;
-    while(interest_row < int_num){ /* THIS LOOP IS THE PROBLEM */
+    while(interest_row < int_num){ 
         if(interact_table[interest_row][0] == 1){
             break;
         }else{
@@ -339,17 +348,25 @@ void land_to_counts(double ***population, int **interact_table, double *paras,
  *     fitnesses: Array to order fitnesses of the agents in the population
  *     jaco: The jacobian matrix of resource and landscape interactions
  *     interact_table: Lookup table for figuring out rows of jaco and types
+ *     agentID: The ID of the agent
  * ========================================================================== */
 void strategy_fitness(double **agent_array, double ***population, double *paras,
-                      double *fitnesses, double **jaco, int **interact_table){
+                      double *fitnesses, double **jaco, int **interact_table,
+                      int agentID){
     
-    int agent, i, row, act_type, int_num, pop_size, ROWS;
+    int agent, i, row, act_type, int_num, pop_size, ROWS, n_agents, a_row;
     double *count_change, *utilities;
     
     pop_size = (int) paras[21];
+    n_agents = (int) paras[54];
     int_num  = (int) paras[60];
     ROWS     = (int) paras[68];
     
+    a_row = 0;
+    while(agent_array[a_row][0] != agentID && a_row < n_agents){
+      a_row++;
+    }
+    
     count_change = malloc(int_num * sizeof(double));
     utilities    = malloc(int_num * sizeof(double));
     
@@ -362,12 +379,14 @@ void strategy_fitness(double **agent_array, double ***population, double *paras,
             act_type   = (int) population[row][0][agent];
             switch(act_type){
                 case -2:
-                    res_to_counts(population, interact_table, paras,
-                                  count_change, utilities, jaco, row, agent);
+                    res_to_counts(population, interact_table, paras, 
+                                  count_change, utilities, jaco, row, agent,
+                                  agent_array, a_row);
                     break;
                 case -1:
                     land_to_counts(population, interact_table, paras, utilities, 
-                                   row, agent, jaco, count_change);
+                                   row, agent, jaco, count_change, agent_array,
+                                   a_row);
                     break;
                 default:
                     break;
@@ -382,7 +401,6 @@ void strategy_fitness(double **agent_array, double ***population, double *paras,
     free(count_change);
 }
 
-
 /* =============================================================================
  * This function ensures that managers cannot make some actions too cheap
  *    population: array of the population that is made
@@ -503,11 +521,7 @@ void policy_to_counts(double ***population, double **merged_acts, int agent,
         new_act  = new_action(old_cost, new_cost, old_act);
         
         act_change[action_row][col] = new_act;
-        /*
-        if(col == 8 && action_row == 0){
-            printf("%d\t%f\t%f\t%f\t%f\t%f\n", gen, old_cost, new_cost, old_act, new_act, act_change[0][8]);       
-        }
-         */
+
     }
 }
 
@@ -528,14 +542,20 @@ void manager_fitness(double *fitnesses, double ***population, double **jaco,
                      double ***COST, double ***ACTION, double *paras, int gen){
     
     int agent, i, j, m_lyr, action_row, manager_row, type1, type2, type3;
-    int pop_size, int_num, ROWS, COLS;
+    int pop_size, int_num, ROWS, COLS, psc, pcu, pca, pfe, phe, n_agents;
     double *count_change, foc_effect, change_dev, max_dev;
     double *dev_from_util, *utils, **merged_acts, **merged_costs, **act_change;
     
     pop_size = (int) paras[21];
+    n_agents = (int) paras[54];
     int_num  = (int) paras[60];
     ROWS     = (int) paras[68];
     COLS     = (int) paras[69];
+    psc      = (int) paras[74];
+    pcu      = (int) paras[75];
+    pca      = (int) paras[76];
+    pfe      = (int) paras[77];
+    phe      = (int) paras[78];
     
     count_change  = malloc(int_num * sizeof(double));
     utils         = malloc(int_num * sizeof(double));
@@ -554,7 +574,7 @@ void manager_fitness(double *fitnesses, double ***population, double **jaco,
     }
     
     m_lyr = 0;
-    while(agent_array[m_lyr][0] != agentID && m_lyr < ROWS){
+    while(agent_array[m_lyr][0] != agentID && m_lyr < n_agents){
         m_lyr++;
     }
     
@@ -564,22 +584,12 @@ void manager_fitness(double *fitnesses, double ***population, double **jaco,
     for(i = 0; i < ROWS; i++){ /* Actions > 0 to respond to possible change */
         for(j = 7; j < COLS; j++){
             merged_acts[i][j] += paras[95];
-            /* printf("%f\t",merged_costs[i][j]);*/
         }
-        /* printf("\n"); */
     }
-/*
-    printf("\n");
-  */      
+
     max_dev = 0;
     for(agent = 0; agent < pop_size; agent++){
         for(action_row = 0; action_row < int_num; action_row++){
-            
-            
-            
-            
-            
-            
             count_change[action_row] = 0; 
             utils[action_row]        = 0; 
             manager_row              = 0;
@@ -595,27 +605,16 @@ void manager_fitness(double *fitnesses, double ***population, double **jaco,
             }
             policy_to_counts(population, merged_acts, agent, merged_costs, 
                              act_change, action_row, manager_row, paras, gen);
-            foc_effect  = 0.0;
-            foc_effect  += (paras[74] * paras[88] * act_change[action_row][7]);
-            foc_effect  += (paras[75] * paras[89] * act_change[action_row][8]);
-            foc_effect  += (paras[76] * paras[90] * act_change[action_row][9]);
-            foc_effect  += (paras[77] * paras[91] * act_change[action_row][10]);
-            foc_effect  += (paras[78] * paras[92] * act_change[action_row][11]);
+            foc_effect   = 0.0;
+            foc_effect  += agent_array[m_lyr][psc] * act_change[action_row][7]; 
+            foc_effect  += agent_array[m_lyr][pcu] * act_change[action_row][8]; 
+            foc_effect  += agent_array[m_lyr][pca] * act_change[action_row][9]; 
+            foc_effect  += agent_array[m_lyr][pfe] * act_change[action_row][10];
+            foc_effect  += agent_array[m_lyr][phe] * act_change[action_row][11];
             for(i = 0; i < int_num; i++){
                 count_change[i] += foc_effect * jaco[action_row][i];
             }
             utils[action_row] = ACTION[manager_row][4][m_lyr];
-        
-        
-        /*
-            if(action_row == 0){
-                printf("%d\t%d\t%f\t%f\t%f\t%f\t%f\t", gen, agent, utils[0],
-                       act_change[0][8], foc_effect,
-                       count_change[0], jaco[0][0]);
-            }
-          */  
-            
-            
         }
         change_dev = 0;
         for(i = 0; i < int_num; i++){
@@ -625,8 +624,6 @@ void manager_fitness(double *fitnesses, double ***population, double **jaco,
             max_dev = change_dev;
         }
         dev_from_util[agent] = change_dev;
-        
-        
     }
     for(agent = 0; agent < pop_size; agent++){
         fitnesses[agent] = max_dev - dev_from_util[agent];
@@ -818,10 +815,17 @@ void ga(double ***ACTION, double ***COST, double **AGENT, double **RESOURCES,
     generations    = (int) paras[22];
     xdim           = (int) paras[68];
     ydim           = (int) paras[69];
-    converge_crit  = paras[98];
-    budget         = (double) AGENT[agent][16];
-    agentID        = AGENT[agent][0];
+    converge_crit  = (double)paras[98];
+    agentID        = (int) AGENT[agent][0];
+    
     most_fit       = 0;
+    budget         = AGENT[agent][16] + AGENT[agent][24] + AGENT[agent][25]; 
+    if(budget < 1){
+      budget = 1;
+    }
+    if(budget > 100001){
+      budget = 100000;
+    }
     
     POPULATION = malloc(xdim * sizeof(double *));
     for(row = 0; row < xdim; row++){
@@ -863,10 +867,9 @@ void ga(double ***ACTION, double ***COST, double **AGENT, double **RESOURCES,
             apply_min_costs(POPULATION, paras, agentID);
             manager_fitness(fitnesses, POPULATION, JACOBIAN, AGENT, lookup, 
                             agentID, COST, ACTION, paras, gen);
-            /*      printf("%d\t%f\t%f\n", gen, POPULATION[2][4][0], POPULATION[2][8][0]);   */
         }else{
             strategy_fitness(AGENT, POPULATION, paras, fitnesses, JACOBIAN, 
-                             lookup); 
+                             lookup, agentID); 
         }
   
         tournament(fitnesses, winners, paras);
