@@ -30,12 +30,14 @@ void add_time(double **res_adding, double *paras){
  * ========================================================================== */
 void res_add(double **res_adding, double *paras){
     
-    int resource_number, add, realised, type, K_add, gadj, oadj, cadj;
-    int resource, sampled, added, loops, castrated, killed, klld;
-    double rand_pois, base_lambda, add_lambda, lambda;
+    int resource_number, add, realised, type, K_add, gadj, oadj, cadj, ind_age;
+    int land_add, ccl;
+    int resource, sampled, added, loops, castrated, killed, klld, arp, age;
+    double rand_pois, rand_off, base_lambda, add_lambda, lambda, crp;
     
     type            = (int) paras[3];  /* Type of growth (e.g., poisson) */
     K_add           = (int) paras[5];  /* Carrying capacity applied  */
+    age             = (int) paras[31]; /* Age column for the individual */
     resource_number = (int) paras[32];
     add             = (int) paras[37];
     realised        = (int) paras[38];
@@ -43,19 +45,44 @@ void res_add(double **res_adding, double *paras){
     oadj            = (int) paras[40]; /* Adjustment to offspring number col */
     klld            = (int) paras[42]; /* Adjustment to kill */
     cadj            = (int) paras[73]; /* Adjust to castrate */
+    arp             = (int) paras[111]; /* Minimum age of reproduction */
+    ccl             = (int) paras[115]; /* Column for holding consumption */
+    crp             = paras[117]; /* Consumption required for one offspring */
 
     added = 0; 
     switch(type){
         case 0:
             break;
         case 1:
-            break; /* Add in a different type of birth here */
+            for(resource = 0; resource < resource_number; resource++){
+                res_adding[resource][realised] = 0;
+                castrated = res_adding[resource][cadj];
+                killed    = res_adding[resource][klld];
+                ind_age   = res_adding[resource][age];
+                if(castrated >= 1 || killed >= 1 || ind_age < arp){
+                    rand_off = 0;
+                }else{
+                    base_lambda = res_adding[resource][add];
+                    add_lambda  = base_lambda * res_adding[resource][gadj];
+                    lambda      = base_lambda + add_lambda;
+                    if(lambda < 0){
+                        lambda = 0;
+                    }
+                    rand_off  = lambda;
+                    rand_off += res_adding[resource][oadj];
+                    rand_off  = floor(rand_off);
+                    res_adding[resource][realised] = rand_off;
+                }
+                added += (int) rand_off;
+            }
+            break;
         case 2:
             for(resource = 0; resource < resource_number; resource++){
                 res_adding[resource][realised] = 0;
                 castrated = res_adding[resource][cadj];
                 killed    = res_adding[resource][klld];
-                if(castrated >= 1 || killed >= 1){
+                ind_age   = res_adding[resource][age];
+                if(castrated >= 1 || killed >= 1 || ind_age < arp){
                     rand_pois = 0;
                 }else{
                     base_lambda = res_adding[resource][add];
@@ -76,7 +103,8 @@ void res_add(double **res_adding, double *paras){
                 res_adding[resource][realised] = 0;
                 castrated = res_adding[resource][cadj];
                 killed    = res_adding[resource][klld];
-                if(castrated >= 1 || killed >= 1){
+                ind_age   = res_adding[resource][age];
+                if(castrated >= 1 || killed >= 1 || ind_age < arp){
                     rand_pois = 0;
                 }else{
                     base_lambda = res_adding[resource][add];
@@ -93,6 +121,14 @@ void res_add(double **res_adding, double *paras){
             }
             break;
     }
+    for(resource = 0; resource < resource_number; resource++){
+        ind_age   = res_adding[resource][age];
+        if(crp > 0 && ind_age >= arp){
+            land_add = floor(res_adding[resource][ccl] / crp);
+            res_adding[resource][realised] += (int) land_add;
+            added                          += (int) land_add;
+        }
+    }
     if(K_add > 0){ /* If there is a carrying capacity applied to adding */
         loops = 1000000000;
         while(added > K_add){ 
@@ -119,7 +155,7 @@ void res_add(double **res_adding, double *paras){
  * ========================================================================== */
 void res_place(double **make, double **old, double *paras, int res_added){
                
-    int old_number, traits, realised, age;
+    int old_number, traits, realised, age, off_col;
     int resource, newbie, trait, to_make, to_add, last_old;
     double res_index;
     
@@ -127,6 +163,7 @@ void res_place(double **make, double **old, double *paras, int res_added){
     old_number = (int) paras[32];
     realised   = (int) paras[38];
     traits     = (int) paras[41];
+    off_col    = (int) paras[114];
     
     to_make   = 0;
     to_add    = 0; /* Maybe try to cut down the loops here later? */
@@ -139,8 +176,8 @@ void res_place(double **make, double **old, double *paras, int res_added){
             for(trait = 1; trait < traits; trait++){
                 make[newbie][trait] = old[resource][trait];
             }
-            make[newbie][age] = 0; /* A bit inefficient given loop above */
-            make[newbie][10]  = 0; /* Get rid of hard code (offspring = 0) */
+            make[newbie][age]     = 0; /* A bit inefficient given loop above */
+            make[newbie][off_col] = 0;
             res_index++;
         }
         to_make = to_add;
@@ -156,29 +193,31 @@ void res_place(double **make, double **old, double *paras, int res_added){
  * ========================================================================== */
 void res_remove(double **res_removing, double *paras){
 
-    int resource_number, rm_row, type, K, rm_adj, max_age, age_col;
+    int resource_number, rm_col, type, K, rm_adj, max_age, age_col, cons_col;
     int resource, over_K;
-    double rand_unif, rm_from_K, rm_from_Ind, base_rm, adj_rm, rm_odds;
+    double rand_unif, rm_from_K, rm_from_Ind, base_rm, adj_rm, rm_odds, csr;
 
     type            = (int) paras[4];
     K               = (int) paras[6]; /* Carrying capacity on removal/death */
     max_age         = (int) paras[29];
     age_col         = (int) paras[31];
     resource_number = (int) paras[32];
-    rm_adj          = (int) paras[42]; /* col in res_adding adjusting removal */
-    rm_row          = (int) paras[43];
+    rm_adj          = (int) paras[42]; /* col in res_removing adjust removal */
+    rm_col          = (int) paras[43];
+    cons_col        = (int) paras[115]; /* col in res_removing of consumption */
+    csr             = paras[116]; /* Consumption required for survival */
     
     switch(type){
         case 0: /* No removal */
             break;
         case 1:
             for(resource = 0; resource < resource_number; resource++){
-                base_rm   = res_removing[resource][rm_row];
+                base_rm   = res_removing[resource][rm_col];
                 adj_rm    = res_removing[resource][rm_adj];
                 rm_odds   = base_rm + adj_rm;
                 rand_unif = runif(0, 1);
                 if(rand_unif < rm_odds){
-                    res_removing[resource][rm_row] = -1;   
+                    res_removing[resource][rm_col] = -1;   
                 }
             }
             break;
@@ -189,7 +228,7 @@ void res_remove(double **res_removing, double *paras){
                 for(resource = 0; resource < resource_number; resource++){
                     rand_unif   = runif(0, 1);
                     if(rand_unif < rm_from_K){
-                        res_removing[resource][rm_row] = -1;   
+                        res_removing[resource][rm_col] = -1;   
                     }
                 }
             }
@@ -197,16 +236,16 @@ void res_remove(double **res_removing, double *paras){
                 rm_from_Ind = res_removing[resource][rm_adj];
                 rand_unif   = runif(0, 1);
                 if(rand_unif < rm_from_Ind){
-                    res_removing[resource][rm_row] = -1;   
+                    res_removing[resource][rm_col] = -1;   
                 }
             }
             break;
         case 3:
             for(resource = 0; resource < resource_number; resource++){
-                rm_odds   = res_removing[resource][rm_row];
+                rm_odds   = res_removing[resource][rm_col];
                 rand_unif = runif(0, 1);
                 if(rand_unif < rm_odds){
-                    res_removing[resource][rm_row] = -1;   
+                    res_removing[resource][rm_col] = -1;   
                 }
             }
             over_K  = resource_number - K;
@@ -215,7 +254,7 @@ void res_remove(double **res_removing, double *paras){
                 for(resource = 0; resource < resource_number; resource++){
                     rand_unif   = runif(0, 1);
                     if(rand_unif < rm_from_K){
-                        res_removing[resource][rm_row] = -1;   
+                        res_removing[resource][rm_col] = -1;   
                     }
                 }
             }
@@ -223,7 +262,7 @@ void res_remove(double **res_removing, double *paras){
                 rm_from_Ind = res_removing[resource][rm_adj];
                 rand_unif   = runif(0, 1);
                 if(rand_unif < rm_from_Ind){
-                    res_removing[resource][rm_row] = -1;   
+                    res_removing[resource][rm_col] = -1;   
                 }
             }
             break;
@@ -234,7 +273,7 @@ void res_remove(double **res_removing, double *paras){
                 for(resource = 0; resource < resource_number; resource++){
                     rand_unif   = runif(0, 1);
                     if(rand_unif < rm_from_K){
-                        res_removing[resource][rm_row] = -1;   
+                        res_removing[resource][rm_col] = -1;   
                     }
                 }
             }
@@ -242,14 +281,17 @@ void res_remove(double **res_removing, double *paras){
                 rm_from_Ind = res_removing[resource][rm_adj];
                 rand_unif   = runif(0, 1);
                 if(rand_unif < rm_from_Ind){
-                   res_removing[resource][rm_row] = -1;   
+                   res_removing[resource][rm_col] = -1;   
                 }
             }
             break;
     }
     for(resource = 0; resource < resource_number; resource++){
         if(res_removing[resource][age_col] > max_age){
-            res_removing[resource][rm_row] = -1;
+            res_removing[resource][rm_col] = -1;
+        }
+        if(res_removing[resource][cons_col] < csr){
+            res_removing[resource][rm_col] = -1;
         }
     }
 }
@@ -296,6 +338,88 @@ void res_landscape_interaction(double **resource_array, double ***landscape,
     }
 }
 
+/* =============================================================================
+ * This function checks to see if a resource population size exceeds its 
+ * carrying capacity as applied to death
+ * Inputs include:
+ *     res_num_total: The total number of resources in the population
+ *     paras: Global parameters needed
+ * ========================================================================== */
+void resource_over_death_K(int res_num_total, double *paras){
+    
+    int death_K;
+    
+    death_K = (int) paras[6];
+    
+    paras[108] = 0;
+    if(res_num_total > death_K){
+        paras[108] = 1;
+    }
+}
+
+
+/* =============================================================================
+ * This function models a single resource eating on the landscape
+ * ========================================================================== */
+void resource_feeds(double **resource_array, double ***landscape, double *paras,
+                    int resource){
+
+    int resource_effect, landscape_layer, x_col, y_col, x_pos, y_pos, cons_col;
+    double c_rate, consumed;
+    
+    x_col             = (int) paras[33];
+    y_col             = (int) paras[34];
+    resource_effect   = (int) paras[47];
+    landscape_layer   = (int) paras[48];
+    cons_col          = (int) paras[115]; /* col in res_removing of consump */
+    
+    x_pos    = (int) resource_array[resource][x_col];
+    y_pos    = (int) resource_array[resource][y_col];
+    c_rate   = resource_array[resource][resource_effect];
+    consumed = c_rate * landscape[x_pos][y_pos][landscape_layer];
+    
+    resource_array[resource][cons_col]       += consumed;
+    landscape[x_pos][y_pos][landscape_layer] -= consumed;
+}
+
+/* =============================================================================
+ * This function models the process of resources feeding on the landscape
+ * ========================================================================== */
+void resource_feeding(double **resource_array, double ***landscape,
+                      double *paras, int resource_number){
+    
+    int resource, fed_col, tot_fed, is_dead, rm_row;
+    int *fed;
+    
+    fed_col = (int) paras[118]; /* Location of the column tracking fed */
+    rm_row  = (int) paras[42];  /* Has the resource already died? */
+    tot_fed = 0;
+
+    fed = (int *) malloc(resource_number * sizeof(int));
+    for(resource = 0; resource < resource_number; resource++){
+        is_dead = resource_array[resource][rm_row];
+        if(is_dead < 1){
+            fed[resource]  = resource_array[resource][fed_col];
+            tot_fed       += fed[resource];
+        }
+    }
+    
+    while(tot_fed > 0){
+        
+        do{ /* This will find a resource with feeding actions left */
+            resource = get_rand_int(0, resource_number);
+        } while(fed[resource] == 0);
+                    
+        resource_feeds(resource_array, landscape, paras, resource);
+        
+        move_a_resource(resource_array, landscape, paras, resource);
+        
+        fed[resource]--;
+        tot_fed--;
+    }
+}
+
+
 /* =============================================================================
  * MAIN RESOURCE FUNCTION:
  * ===========================================================================*/
@@ -332,6 +456,7 @@ SEXP resource(SEXP RESOURCE, SEXP LANDSCAPE, SEXP PARAMETERS){
     int len_PARAMETERS;      /* Length of the parameters vector */
     int *dim_RESOURCE;       /* Dimensions of the RESOURCE array incoming */
     int *dim_LANDSCAPE;      /* Dimensions of the LANDSCAPE array incoming */
+    double csr, crp, tfe;    /* Consumption requirements, surv, rep, feeding */
     double *R_ptr;           /* Pointer to RESOURCE (interface R and C) */
     double *R_ptr_new;       /* Pointer to RESOURCE_NEW (interface R and C) */
     double *land_ptr;        /* Pointer to LANDSCAPE (interface R and C) */
@@ -418,13 +543,20 @@ SEXP resource(SEXP RESOURCE, SEXP LANDSCAPE, SEXP PARAMETERS){
     
     off_col   = (int) paras[38];
     rm_col    = (int) paras[43];
+    csr       = paras[116]; /* Consumption required for survival */
+    crp       = paras[117]; /* Consumption needed for one offspring */
+    tfe       = paras[124]; /* Times a resource feeds in one time step */
     
     /* Resource time step and age needs to be increased by one */
     add_time(res_old, paras);
-    
-    /* Resources move according to move function and parameter) */
-    res_mover(res_old, land, paras);
 
+    /* If we need to get amount eaten because it affects death or birth*/
+    if(csr > 0 || crp > 0 || tfe > 1){ 
+        resource_feeding(res_old, land, paras, res_number);
+    }else{ /* One-off resources affect the landscape */
+        res_landscape_interaction(res_old, land, paras, res_number); 
+    }
+    
     /* Identify, and calculate the number of, added individuals */
     res_add(res_old, paras);
     res_nums_added = 0; 
@@ -448,7 +580,8 @@ SEXP resource(SEXP RESOURCE, SEXP LANDSCAPE, SEXP PARAMETERS){
     }
     
     res_num_total = res_number + res_nums_added - res_nums_subtracted;
-
+    paras[32]     = (double) res_num_total;
+    
     /* Below makes a new array for new RESOURCE, then adds it */
     res_new = malloc(res_num_total * sizeof(double *));
     for(resource = 0; resource < res_num_total; resource++){
@@ -467,6 +600,7 @@ SEXP resource(SEXP RESOURCE, SEXP LANDSCAPE, SEXP PARAMETERS){
             res_new[resource_new][17] = 0;
             res_new[resource_new][18] = 0;
             res_new[resource_new][19] = 0;
+            res_new[resource_new][20] = 0;
             resource_new++; /* Move on to the next new resource */
         }
     }
@@ -479,12 +613,16 @@ SEXP resource(SEXP RESOURCE, SEXP LANDSCAPE, SEXP PARAMETERS){
         res_new[resource_new][17] = 0;
         res_new[resource_new][18] = 0;
         res_new[resource_new][19] = 0;
+        res_new[resource_new][20] = 0;
         resource_new++;
     }
     
-    /* Resources affect the landscape (note the **ORDER** of this -- change? */
-    res_landscape_interaction(res_new, land, paras, res_num_total);
-        
+    /* Resources move according to move function and parameter) */
+    res_mover(res_new, land, paras);
+    
+    /* Check to see if the population is over carrying capacity */
+    resource_over_death_K(res_num_total, paras);
+
     /* This code switches from C back to R */
     /* ====================================================================== */        
     
@@ -501,7 +639,6 @@ SEXP resource(SEXP RESOURCE, SEXP LANDSCAPE, SEXP PARAMETERS){
             vec_pos++;
         }
     } 
-    paras[32] = (double) res_num_total;
     
     SEXP LAND_NEW;
     PROTECT( LAND_NEW = alloc3DArray(REALSXP, land_x, land_y, land_z) );
