@@ -50,40 +50,6 @@ void send_agents_home(double **agent_array, double ***land, double *paras){
     }
 }
 
-/* =============================================================================
- * This function counts the cell yield on a landscape layer
- * Inputs include:
- *     agent_array: The array of agents
- *     land: The landscape array
- *     paras: Vector of global parameters used in the model
- * ========================================================================== */
-void count_cell_yield(double **agent_array, double ***land, double *paras){
-
-    int land_x, land_y, agent_number, yield_layer, own_layer, yield_column;
-    int xpos, ypos, agent, agent_ID;
-    double agent_yield;
-    
-    land_x       = (int) paras[12];
-    land_y       = (int) paras[13];
-    agent_number = (int) paras[54];
-    yield_layer  = (int) paras[80];
-    own_layer    = (int) paras[81];
-    yield_column = (int) paras[82];
-    
-    for(agent = 0; agent < agent_number; agent++){
-        agent_ID    = agent_array[agent][0];
-        agent_yield = 0.0; 
-        for(xpos = 0; xpos < land_x; xpos++){
-            for(ypos = 0; ypos < land_y; ypos++){
-                if(land[xpos][ypos][own_layer] == agent_ID){
-                    agent_yield += land[xpos][ypos][yield_layer];    
-                }
-            }
-        }
-        agent_array[agent][yield_column] = agent_yield; 
-    }
-}
-
 /* =============================================================================
  *  This function clones action arrays so actions can be decremented temporarily
  *  Inputs include:
@@ -386,6 +352,7 @@ void do_acts(double ***action_array, double **resource_array, double *paras,
  *      action_array: An array of the action of agents
  *      from: The layer of the action array to be copied
  *      to: The layer of the action array to copy to
+ *      paras: Vector of global parameters used in the model
  * ========================================================================== */
 void copycat(double ***action_array, int from, int to, double *paras){
     
@@ -402,6 +369,31 @@ void copycat(double ***action_array, int from, int to, double *paras){
     }
 }
 
+/* =============================================================================
+ * This adds more budget to a column in agent_array based on agent yield
+ * Inputs include:
+ *     action_array: An array of the action of agents
+ *     paras: Vector of global parameters used in the model
+ * ========================================================================== */
+void yield_to_budget(double **agent_array, double *paras){   
+    
+    int agent, N_agents, agent_type, y_bonus_col, yield_col;
+    double yield_budget, yield_incr;
+    
+    N_agents     = (int) paras[54];
+    yield_col    = (int) paras[82];
+    yield_budget = (double) paras[125]; 
+    y_bonus_col  = (int) paras[128];
+
+    for(agent = 0; agent < N_agents; agent++){
+        agent_type = agent_array[agent][1];   
+        if(agent_type == 1) {
+            yield_incr = agent_array[agent][yield_col] * yield_budget;
+            agent_array[agent][y_bonus_col] = floor(yield_incr);
+        }
+    }
+}
+
 /* =============================================================================
  * MAIN OBSERVATION FUNCTION:
  * ===========================================================================*/
@@ -446,6 +438,7 @@ SEXP user(SEXP RESOURCE, SEXP LANDSCAPE, SEXP PARAMETERS, SEXP AGENT, SEXP COST,
     int protected_n;         /* Number of protected R objects */
     int vec_pos;             /* Vector position for making arrays */
     int group_think;         /* Should one user do the thinking for all */
+    double yield_budget;     
     int len_PARAMETERS;      /* Length of the parameters vector */
     int *dim_RESOURCE;       /* Dimensions of the RESOURCE array incoming */
     int *dim_LANDSCAPE;      /* Dimensions of the LANDSCAPE array incoming */
@@ -661,10 +654,19 @@ SEXP user(SEXP RESOURCE, SEXP LANDSCAPE, SEXP PARAMETERS, SEXP AGENT, SEXP COST,
     /* Do the biology here now */
     /* ====================================================================== */
     
-    group_think = (int) paras[101];
+    group_think  = (int) paras[101];
+    yield_budget = (double) paras[125];
     
     send_agents_home(agent_array, land, paras);
     
+    count_owned_cells(land, paras, agent_array, land_x, land_y, agent_number);
+    
+    count_cell_yield(agent_array, land, paras);
+    
+    if(yield_budget != 0) {
+        yield_to_budget(agent_array, paras);
+    }
+    
     if(group_think > 0 && agent_number > 2){
         ga(actions, costs, agent_array, resource_array, land, Jacobian_mat,
            lookup, paras, 1, 0);
@@ -680,8 +682,6 @@ SEXP user(SEXP RESOURCE, SEXP LANDSCAPE, SEXP PARAMETERS, SEXP AGENT, SEXP COST,
     
     do_acts(actions, resource_array, paras, land);
 
-    count_cell_yield(agent_array, land, paras);
-    
     /* This code switches from C back to R */
     /* ====================================================================== */        
     
